searchNodes=[{"ref":"AuthZ.AuthorizationPlugMixin.html","title":"AuthZ.AuthorizationPlugMixin","type":"behaviour","doc":"Allows to create a plug enforcing authorization for protected routes. A user-defined module must use this module, making the user module a plug, and implement the handle_authorization/3 and handle_authentication_error/2 behaviours. The handle_authorization/3 and handle_authentication_error/2 callbacks receive a Plug.Conn struct and an atom identifying the set of routes that require authorization, and must return a Plug.Conn struct; handle_authorization/3 additionally receives the logged in user. Example: defmodule MyAppWeb.Plugs.EnsureAuthorized do use AuthZ.AuthorizationPlugMixin import Plug.Conn import Phoenix.Controller alias MyApp.Accounts.User def handle_authentication_error(conn, :admin_routes), do: conn |&gt; put_status(401) |&gt; text(&quot;unauthenticated&quot;) |&gt; halt() def handle_authorization(conn, %User{type: &quot;admin&quot;}, :admin_routes), do: conn def handle_authorization(conn, _, _), do: conn |&gt; put_status(403) |&gt; text(&quot;unauthorized&quot;) |&gt; halt() end EnsureAuthorized is now a plug which can be used in the router: pipeline :ensure_admin_routes_authorized do plug MyAppWeb.Plugs.EnsureAuthorized, resource: :admin_routes end scope &quot;/admin&quot;, MyAppWeb, as: :admin do pipe_through [:browser, :ensure_admin_routes_authorized] # code end"},{"ref":"AuthZ.AuthorizationPlugMixin.html#c:handle_authentication_error/2","title":"AuthZ.AuthorizationPlugMixin.handle_authentication_error/2","type":"callback","doc":""},{"ref":"AuthZ.AuthorizationPlugMixin.html#c:handle_authorization/3","title":"AuthZ.AuthorizationPlugMixin.handle_authorization/3","type":"callback","doc":""},{"ref":"AuthZ.Authorizer.html","title":"AuthZ.Authorizer","type":"behaviour","doc":"Declares the authorize/3 callback to be implemented by context modules. The authorize/3 function should receive an atom describing the action, the logged in user and the resource intended to be accessed; the function should return :ok in case the action is authorized, or a tuple containing :error as its first element and an atom describing the reason of unauthorized access as its second element (allowing to return different possible reasons of failure allows the controller for example to send more specific error messages to the logs or the view). Example: defmodule MyApp.Post.Policy do use AuthZ.Authorizer alias MyApp.Accounts.User alias MyApp.Blog.Post @unauthorized {:error, :unauthorized} def authorize(:edit_question, %User{id: user_id}, %Post{author: user_id}) do :ok end def authorize(:edit_question, _, _) do @unauthorized end end Using (use) this module injects the authorized?/3 function simply calling authorize/3 and returning a boolean instead of a tuple."},{"ref":"AuthZ.Authorizer.html#c:authorize/3","title":"AuthZ.Authorizer.authorize/3","type":"callback","doc":""},{"ref":"readme.html","title":"AuthZ","type":"extras","doc":"AuthZ AuthZ is a simple authorization library that allows you to ensure users are permitted to access protected routes; encourage authorization rules in contexts."},{"ref":"readme.html#implementing-authorization-rules-in-contexts","title":"AuthZ - Implementing authorization rules in contexts","type":"extras","doc":"Authorization is easy to implement using the power of pattern matching. Below is an example where only authors are authorized to edit their posts. use AuthZ.Authorizer simply injects a behaviour, requiring your module to implement authorize/3. This function should receive an atom describing the action, the logged in user and the resource intended to be accessed; the function should return :ok in case the action is authorized, or a tuple containing :error as its first element and an atom describing the reason of unauthorized access as its second element (allowing to return different possible reasons of failure allows the controller for example to send more specific error messages to the logs or the view). defmodule MyApp.Post.Policy do use AuthZ.Authorizer alias MyApp.Accounts.User alias MyApp.Blog.Post @unauthorized {:error, :unauthorized} def authorize(:edit_question, %User{id: user_id}, %Post{author: user_id}) do :ok end def authorize(:edit_question, _, _) do @unauthorized end end use AuthZ.Authorizer also injects the function authorized?/3 which simply calls the user-defined function authorize/3 and returns a boolean indicating authorization success or failure."},{"ref":"readme.html#protecting-routes-against-unauthorized-users","title":"AuthZ - Protecting routes against unauthorized users","type":"extras","doc":"Authorization can be enforced for some routes. Create a module using (use) the AuthZ.AuthorizationPlugMixin module; then implement the callbacks handle_authentication_error/2 and handle_authorization/3. Both callbacks receive a Plug.Conn struct and an atom identifying the set of routes that require authentication; handle_authorization/3 additionally receives the logged in user. defmodule MyAppWeb.Plugs.EnsureAuthorized do use AuthZ.AuthorizationPlugMixin import Plug.Conn import Phoenix.Controller alias MyApp.Accounts.User def handle_authentication_error(conn, :admin_routes), do: conn |&gt; put_status(401) |&gt; text(&quot;unauthenticated&quot;) |&gt; halt() def handle_authorization(conn, %User{type: &quot;admin&quot;}, :admin_routes), do: conn def handle_authorization(conn, _, _), do: conn |&gt; put_status(403) |&gt; text(&quot;unauthorized&quot;) |&gt; halt() end You may then use the new plug into a pipeline and ensure that routes requiring authorization are accessed by authorized users only. pipeline :ensure_admin_routes_authorized do plug MyAppWeb.Plugs.EnsureAuthorized, resource: :admin_routes end scope &quot;/admin&quot;, MyAppWeb, as: :admin do pipe_through [:browser, :ensure_admin_routes_authorized] # code end"},{"ref":"readme.html#installation","title":"AuthZ - Installation","type":"extras","doc":"Add auth_z for Elixir as a dependency in your mix.exs file: def deps do [ {:auth_z, &quot;~&gt; 0.2.0&quot;} ] end"},{"ref":"readme.html#hexdocs","title":"AuthZ - HexDocs","type":"extras","doc":"HexDocs documentation can be found at https://hexdocs.pm/auth_z."}]